<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail Emoticons plugin           |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['emoticonsdisplay'] = 'Прикажи емотиконе у обичним текстуалним порукама';
$labels['emoticonscompose'] = 'Укључи емотиконе';
