<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Паказваць апавяшчэнні аб атрыманні новых паведамленняў у браўзеры';
$labels['desktop'] = 'Паказваць апавяшчэнні аб атрыманні новых паведамленняў на працоўным стале';
$labels['sound'] = 'Агучваць атрыманне новых паведамленняў';
$labels['test'] = 'Праверыць';
$labels['title'] = 'Новы ліст!';
$labels['body'] = 'Вы атрымалі новае паведамленне.';
$labels['testbody'] = 'Гэта тэставае апавяшчэнне.';
$labels['desktopdisabled'] = 'Апавяшчэнні на працоўным стале адключаныя ў браўзеры.';
$labels['desktopunsupported'] = 'Ваш браўзер не падтрымлівае апавяшчэнні на працоўным стале.';
$labels['desktoptimeout'] = 'Зачыніць апавяшчэнне на працоўным стале';
